from .pyGPUreg import *

VERSION = '0.0.7'
AUTHOR = "Mart G. F. Last"
CONTACT = "m.g.f.last@lumc.nl"




